@@ -47,9 +47,9 @@ bmRequest <- function(request, httr_config, verbose = FALSE){
                         timeout(getOption("timeout", default = 60)))
     stop_for_status(result)
 
-    result2 <- content(result, encoding = "UTF-8")
+    result2 <- content(result, encoding = "UTF-8", as = "text")
     if(is.na(result2)) {
-        result2 <- content(result, encoding = "Latin1")
+        result2 <- content(result, encoding = "Latin1", as = "text")
     }
     return(result2)
 }
@@ -115,7 +115,7 @@ listMarts <- function( mart = NULL, host="https://www.ensembl.org", path="/bioma
     if(!grepl(x = registry, pattern = "^\n*<MartRegistry>")) {
         
         if(grepl(x = registry, pattern = "status.ensembl.org")) {
-            stop("Your query has been redirected to http://status.ensembl.org ",
+            stop("Your query has been redirected to https://status.ensembl.org ",
                  "indicating this Ensembl service is currently unavailable.",
                  "\nLook at ?useEnsembl for details on how to try a mirror site.",
                  call. = FALSE)
