@@ -121,7 +121,7 @@
         return("")
     }
     ## if we have multiple filters, the values must be specified as a list.
-    if(length(filters) > 1 && class(values) != "list") {
+    if(length(filters) > 1 && !is.list(values)) {
         stop("If using multiple filters, the 'value' has to be a list.",
         "\nFor example, a valid list for 'value' could be: list(affyid=c('1939_at','1000_at'), chromosome= '16')",
         "\nHere we select on Affymetrix identifier and chromosome, only results that pass both filters will be returned");
